@@ -6,14 +6,15 @@ package Fierce::Parser::Domain::ARIN;
 
     use Object::InsideOut;
 
-    my @result : Field : Arg(result) : Get(result) : Type(List(Fierce::Parser::RangeResult));
+    my @result : Field : Arg(result) : Get(result) :
+        Type(List(Fierce::Parser::RangeResult));
 
     my @query : Field : Arg(query) : Get(query);
-   
+
     my @starttime : Field : Arg(starttime) : Get(starttime);
     my @endtime : Field : Arg(endtime) : Get(endtime);
     my @starttimestr : Field : Arg(starttimestr) : Get(starttimestr);
     my @endtimestr : Field : Arg(endtimestr) : Get(endtimestr);
-    my @elasptime : Field : Arg(elasptime) : Get(elasptime);
+    my @elapsedtime : Field : Arg(elapsedtime) : Get(elapsedtime);
 }
 1;
